import { transformError as sdkTransformError } from '@wix/sdk-runtime/transform-error';
import { renameKeysFromSDKRequestToRESTRequest, renameKeysFromRESTResponseToSDKResponse, } from '@wix/sdk-runtime/rename-all-nested-keys';
import * as ambassadorWixMembersV1CustomFieldSuggestion from './members-v1-custom-field-suggestion-custom-field-suggestion.http.js';
export var Privacy;
(function (Privacy) {
    /** Unknown privacy. This value isn't used. */
    Privacy["UNKNOWN"] = "UNKNOWN";
    /** The information appears on the members' public profile pages. */
    Privacy["PUBLIC"] = "PUBLIC";
    /** Only the member can see this information. */
    Privacy["PRIVATE"] = "PRIVATE";
})(Privacy || (Privacy = {}));
export var Type;
(function (Type) {
    /** Unknown field type. This value isn't used. */
    Type["UNKNOWN"] = "UNKNOWN";
    /** A text box to write any type of text. */
    Type["TEXT"] = "TEXT";
    /** Only number can be entered into the field. */
    Type["NUMBER"] = "NUMBER";
    /** Only date can be entered into the field. */
    Type["DATE"] = "DATE";
    /** Only URL can be entered into the field. */
    Type["URL"] = "URL";
    /** Only link from the selected social media platform can be entered into the field. */
    Type["SOCIAL"] = "SOCIAL";
})(Type || (Type = {}));
export var SocialTypeType;
(function (SocialTypeType) {
    /** Unknown social type. This value isn't used. */
    SocialTypeType["UNKNOWN"] = "UNKNOWN";
    /** Facebook social media platform. */
    SocialTypeType["FACEBOOK"] = "FACEBOOK";
    /** Instagram social media platform. */
    SocialTypeType["INSTAGRAM"] = "INSTAGRAM";
    /** LinkedIn social media platform. */
    SocialTypeType["LINKEDIN"] = "LINKEDIN";
    /** X (Twitter) social media platform. */
    SocialTypeType["TWITTER"] = "TWITTER";
    /** Youtube social media platform. */
    SocialTypeType["YOUTUBE"] = "YOUTUBE";
    /** Pinterest social media platform. */
    SocialTypeType["PINTEREST"] = "PINTEREST";
    /** TikTok social media platform. */
    SocialTypeType["TIKTOK"] = "TIKTOK";
    /** DeviantArt social media platform. */
    SocialTypeType["DEVIANTART"] = "DEVIANTART";
    /** SoundCloud social media platform. */
    SocialTypeType["SOUNDCLOUD"] = "SOUNDCLOUD";
    /** Tumblr social media platform. */
    SocialTypeType["TUMBLR"] = "TUMBLR";
    /** Vimeo social media platform. */
    SocialTypeType["VIMEO"] = "VIMEO";
    /** VKontakte social media platform. */
    SocialTypeType["VKONTAKTE"] = "VKONTAKTE";
    /** Odnoklassniki social media platform. */
    SocialTypeType["ODNOKLASSNIKI"] = "ODNOKLASSNIKI";
    /** Other social media platform. */
    SocialTypeType["OTHER"] = "OTHER";
})(SocialTypeType || (SocialTypeType = {}));
export var Origin;
(function (Origin) {
    /** Unknown field origin. This value isn't used. */
    Origin["UNKNOWN"] = "UNKNOWN";
    /** Custom field created by a Wix user. */
    Origin["CUSTOM"] = "CUSTOM";
    /** Contact type of field. These are default fields that are already provided by Members Area, such as: "birth date", "position", "company". */
    Origin["CONTACT"] = "CONTACT";
    /** System type of field. These are default fields that are already provided by Members Area, such as: "first name", "last name", "email", "phone", "address", "title". */
    Origin["SYSTEM"] = "SYSTEM";
})(Origin || (Origin = {}));
export var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (SortOrder = {}));
/**
 * Retrieves a list of suggestions for both custom fields and predefined fields by the Wix Members Area.
 * @public
 * @documentationMaturity preview
 * @permissionId MEMBERS.CUSTOM_FIELDS_SUGGESTIONS_READ
 * @permissionScope Manage Members
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-MEMBERS
 * @permissionScope Read Members and Contacts - all read permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.READ-MEMBERS-CONTACTS
 * @permissionScope Read Members
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-MEMBERS
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.customfields.suggestions.CustomFieldSuggestions.ListCustomFieldSuggestions
 */
export async function listCustomFieldSuggestions(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        paging: options?.paging,
        sorting: options?.sorting,
    });
    const reqOpts = ambassadorWixMembersV1CustomFieldSuggestion.listCustomFieldSuggestions(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                paging: '$[0].paging',
                sorting: '$[0].sorting',
            },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
/**
 * Retrieves a list of suggestions for both custom fields and predefined fields by the Wix Members Area, given the provided paging, filtering, and sorting.
 *
 * Query Custom Field Suggestions runs with these defaults, which you can override:
 * - `createdDate` is sorted in `ASC` order
 * - `paging.limit` is `100`
 * - `paging.offset` is `0`
 *
 * For field support for filters and sorting, see [Supported Filters and Sorting](https://dev.wix.com/docs/rest/crm/members-contacts/members/custom-fields/custom-field-suggestions/filter-and-sort).
 * To learn about working with _Query_ endpoints, see [API Query Language](https://dev.wix.com/api/rest/getting-started/api-query-language), [Sorting and Paging](https://dev.wix.com/api/rest/getting-started/pagination), and [Field Projection](https://dev.wix.com/api/rest/getting-started/field-projection).
 * @public
 * @documentationMaturity preview
 * @permissionId MEMBERS.CUSTOM_FIELDS_SUGGESTIONS_READ
 * @permissionScope Manage Members
 * @permissionScopeId SCOPE.DC-MEMBERS.MANAGE-MEMBERS
 * @permissionScope Read Members and Contacts - all read permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.READ-MEMBERS-CONTACTS
 * @permissionScope Read Members
 * @permissionScopeId SCOPE.DC-MEMBERS.READ-MEMBERS
 * @permissionScope Manage Members and Contacts - all permissions
 * @permissionScopeId SCOPE.DC-CONTACTS-MEGA.MANAGE-MEMBERS-CONTACTS
 * @applicableIdentity APP
 * @fqn com.wixpress.members.customfields.suggestions.CustomFieldSuggestions.QueryCustomFieldSuggestions
 */
export async function queryCustomFieldSuggestions(options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = renameKeysFromSDKRequestToRESTRequest({
        query: options?.query,
    });
    const reqOpts = ambassadorWixMembersV1CustomFieldSuggestion.queryCustomFieldSuggestions(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return renameKeysFromRESTResponseToSDKResponse(result.data);
    }
    catch (err) {
        const transformedError = sdkTransformError(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { query: '$[0].query' },
            singleArgumentUnchanged: false,
        }, ['options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
//# sourceMappingURL=members-v1-custom-field-suggestion-custom-field-suggestion.universal.js.map